@@ -10,10 +10,6 @@ describe 'nova::api' do
     { :admin_password => 'passw0rd' }
   end
 
-  let :facts do
-    @default_facts.merge({ :processorcount => 5 })
-  end
-
   shared_examples 'nova-api' do
 
     context 'with default parameters' do
@@ -67,6 +63,11 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'nova')
         is_expected.to contain_nova_config('DEFAULT/fping_path').with('value' => '/usr/sbin/fping')
         is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/metadata_cache_expiration').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_jsonfile_path').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_max_limit').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_link_prefix').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_glance_link_prefix').with('value' => '<SERVICE DEFAULT>')
       end
 
       it 'unconfigures neutron_metadata proxy' do
@@ -97,6 +98,11 @@ describe 'nova::api' do
           :metadata_workers                     => 2,
           :default_floating_pool                => 'public',
           :enable_proxy_headers_parsing         => true,
+          :metadata_cache_expiration            => 15,
+          :vendordata_jsonfile_path             => '/tmp',
+          :osapi_max_limit                      => 1000,
+          :osapi_compute_link_prefix            => 'https://10.0.0.1:7777/',
+          :osapi_glance_link_prefix             => 'https://10.0.0.1:6666/',
           :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
         })
       end
@@ -141,6 +147,11 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
         is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'public')
+        is_expected.to contain_nova_config('DEFAULT/metadata_cache_expiration').with('value' => '15')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_jsonfile_path').with('value' => '/tmp')
+        is_expected.to contain_nova_config('DEFAULT/osapi_max_limit').with('value' => '1000')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_link_prefix').with('value' => 'https://10.0.0.1:7777/')
+        is_expected.to contain_nova_config('DEFAULT/osapi_glance_link_prefix').with('value' => 'https://10.0.0.1:6666/')
         is_expected.to contain_nova_config('neutron/service_metadata_proxy').with('value' => true)
         is_expected.to contain_nova_config('neutron/metadata_proxy_shared_secret').with('value' => 'secrete')
         is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => true)
@@ -329,44 +340,25 @@ describe 'nova::api' do
 
   end
 
-  context 'on Debian platforms' do
-    before do
-      facts.merge!(
-        :osfamily                  => 'Debian',
-        :operatingsystem           => 'Debian',
-        :operatingsystemrelease    => '8.0',
-        :operatingsystemmajrelease => '8',
-        :concat_basedir            => '/var/lib/puppet/concat',
-        :fqdn                      => 'some.host.tld',
-      )
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({ :processorcount => 5 }))
+      end
 
-    let :platform_params do
-      { :nova_api_package => 'nova-api',
-        :nova_api_service => 'nova-api' }
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :nova_api_package => 'nova-api',
+            :nova_api_service => 'nova-api' }
+        when 'RedHat'
+          { :nova_api_package => 'openstack-nova-api',
+            :nova_api_service => 'openstack-nova-api' }
+        end
+      end
+      it_behaves_like 'nova-api'
     end
-
-    it_behaves_like 'nova-api'
   end
-
-  context 'on RedHat platforms' do
-    before do
-      facts.merge!(
-        :osfamily                  => 'RedHat',
-        :operatingsystem           => 'RedHat',
-        :operatingsystemrelease    => '7.0',
-        :operatingsystemmajrelease => '7',
-        :concat_basedir            => '/var/lib/puppet/concat',
-        :fqdn                      => 'some.host.tld',
-      )
-    end
-
-    let :platform_params do
-      { :nova_api_package => 'openstack-nova-api',
-        :nova_api_service => 'openstack-nova-api' }
-    end
-
-    it_behaves_like 'nova-api'
-  end
-
 end
