@@ -175,6 +175,21 @@ describe 'nova::compute::libvirt' do
 
       end
     end
+
+    describe 'when manage_libvirt_services is set to false' do
+      context 'without libvirt packages & services' do
+        let :params do
+          { :manage_libvirt_services => false }
+        end
+
+        it { is_expected.not_to contain_package('libvirt') }
+        it { is_expected.not_to contain_service('libvirt') }
+        it { is_expected.not_to contain_package('libvirt-nwfilter') }
+        it { is_expected.not_to contain_service('messagebus') }
+        it { is_expected.not_to contain_service('virtlockd') }
+        it { is_expected.not_to contain_service('virtlogd') }
+      end
+    end
   end
 
 
@@ -303,6 +318,21 @@ describe 'nova::compute::libvirt' do
       end
     end
 
+    describe 'when manage_libvirt_services is set to false' do
+      context 'without libvirt packages & services' do
+        let :params do
+          { :manage_libvirt_services => false }
+        end
+
+        it { is_expected.not_to contain_package('libvirt') }
+        it { is_expected.not_to contain_service('libvirt') }
+        it { is_expected.not_to contain_package('libvirt-nwfilter') }
+        it { is_expected.not_to contain_service('messagebus') }
+        it { is_expected.not_to contain_service('virtlockd') }
+        it { is_expected.not_to contain_service('virtlogd') }
+      end
+    end
+
     describe 'with default parameters on Fedora' do
       before do
         facts.merge!({ :operatingsystem => 'Fedora', :osfamily => 'RedHat' })
@@ -335,42 +365,38 @@ describe 'nova::compute::libvirt' do
 
   end
 
-  context 'on Debian platforms' do
-    let (:facts) do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-        :os_package_family => 'debian',
-        :operatingsystemmajrelease => '8'
-      })
+  on_supported_os({
+    :supported_oos => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+
+      case [:osfamily]
+      when 'Debian'
+
+        case [:operatingsystem]
+        when 'Debian'
+          let (:facts) do
+            facts.merge!(OSDefaults.get_facts({
+              :os_package_family => 'debian',
+              :operatingsystemmajrelease => '8'}))
+          end
+          it_behaves_like 'debian-nova-compute-libvirt'
+        when 'Ubuntu'
+          let (:facts) do
+            facts.merge!(OSDefaults.get_facts({
+              :os_package_family => 'ubuntu',
+              :operatingsystemmajrelease => '16.04'}))
+          end
+          it_behaves_like 'debian-nova-compute-libvirt'
+        end
+
+      when 'RedHat'
+        let (:facts) do
+          facts.merge!(OSDefaults.get_facts({ :os_package_type => 'rpm' }))
+        end
+        it_behaves_like 'redhat-nova-compute-libvirt'
+      end
     end
-
-    it_behaves_like 'debian-nova-compute-libvirt'
   end
 
-  context 'on Ubuntu platforms' do
-    let (:facts) do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Ubuntu',
-        :os_package_family => 'ubuntu',
-        :operatingsystemmajrelease => '16.04'
-      })
-    end
-
-    it_behaves_like 'debian-nova-compute-libvirt'
-  end
-
-  context 'on RedHat platforms' do
-    let (:facts) do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-        :os_package_type => 'rpm',
-      })
-    end
-
-    it_behaves_like 'redhat-nova-compute-libvirt'
-  end
-
-
 end
