@@ -221,30 +221,26 @@ describe 'nova::compute' do
     end
   end
 
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :nova_compute_package => 'nova-compute',
+            :nova_compute_service => 'nova-compute' }
+        when 'RedHat'
+          { :nova_compute_package => 'openstack-nova-compute',
+            :nova_compute_service => 'openstack-nova-compute' }
+        end
+      end
+      it_behaves_like 'nova-compute'
     end
-
-    let :platform_params do
-      { :nova_compute_package => 'nova-compute',
-        :nova_compute_service => 'nova-compute' }
-    end
-
-    it_behaves_like 'nova-compute'
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :nova_compute_package => 'openstack-nova-compute',
-        :nova_compute_service => 'openstack-nova-compute' }
-    end
-
-    it_behaves_like 'nova-compute'
-  end
 end
