@@ -59,48 +59,60 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
         is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/os_region_name').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('cinder/os_region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/catalog_info').with('value' => 'volumev2:cinderv2:publicURL')
       end
 
+      it 'configures block_device_allocate params' do
+        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('<SERVICE DEFAULT>')
+      end
     end
 
     context 'with overridden parameters' do
 
       let :params do
-        { :debug                              => true,
-          :log_dir                            => '/var/log/nova2',
-          :image_service                      => 'nova.image.local.LocalImageService',
-          :rpc_backend                        => 'rabbit',
-          :rabbit_host                        => 'rabbit',
-          :rabbit_userid                      => 'rabbit_user',
-          :rabbit_port                        => '5673',
-          :rabbit_password                    => 'password',
-          :rabbit_heartbeat_timeout_threshold => '60',
-          :rabbit_heartbeat_rate              => '10',
-          :lock_path                          => '/var/locky/path',
-          :state_path                         => '/var/lib/nova2',
-          :service_down_time                  => '120',
-          :auth_strategy                      => 'foo',
-          :ensure_package                     => '2012.1.1-15.el6',
-          :memcached_servers                  => ['memcached01:11211', 'memcached02:11211'],
-          :host                               => 'test-001.example.org',
-          :notification_driver                => 'ceilometer.compute.nova_notifier',
-          :notification_topics                => 'openstack',
-          :notify_api_faults                  => true,
-          :report_interval                    => '60',
-          :os_region_name                     => 'MyRegion',
-          :use_ipv6                           => true,
-          :upgrade_level_cells                => '1.0.0',
-          :upgrade_level_cert                 => '1.0.0',
-          :upgrade_level_compute              => '1.0.0',
-          :upgrade_level_conductor            => '1.0.0',
-          :upgrade_level_console              => '1.0.0',
-          :upgrade_level_consoleauth          => '1.0.0',
-          :upgrade_level_intercell            => '1.0.0',
-          :upgrade_level_network              => '1.0.0',
-          :upgrade_level_scheduler            => '1.0.0',
-          :purge_config                       => false, }
+        { :debug                                   => true,
+          :log_dir                                 => '/var/log/nova2',
+          :image_service                           => 'nova.image.local.LocalImageService',
+          :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout                    => '30',
+          :rpc_backend                             => 'rabbit',
+          :rabbit_host                             => 'rabbit',
+          :rabbit_userid                           => 'rabbit_user',
+          :rabbit_port                             => '5673',
+          :rabbit_password                         => 'password',
+          :rabbit_heartbeat_timeout_threshold      => '60',
+          :rabbit_heartbeat_rate                   => '10',
+          :lock_path                               => '/var/locky/path',
+          :state_path                              => '/var/lib/nova2',
+          :service_down_time                       => '120',
+          :auth_strategy                           => 'foo',
+          :ensure_package                          => '2012.1.1-15.el6',
+          :memcached_servers                       => ['memcached01:11211', 'memcached02:11211'],
+          :host                                    => 'test-001.example.org',
+          :notification_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
+          :notification_driver                     => 'ceilometer.compute.nova_notifier',
+          :notification_topics                     => 'openstack',
+          :notify_api_faults                       => true,
+          :report_interval                         => '60',
+          :os_region_name                          => 'MyRegion',
+          :use_ipv6                                => true,
+          :upgrade_level_cells                     => '1.0.0',
+          :upgrade_level_cert                      => '1.0.0',
+          :upgrade_level_compute                   => '1.0.0',
+          :upgrade_level_conductor                 => '1.0.0',
+          :upgrade_level_console                   => '1.0.0',
+          :upgrade_level_consoleauth               => '1.0.0',
+          :upgrade_level_intercell                 => '1.0.0',
+          :upgrade_level_network                   => '1.0.0',
+          :upgrade_level_scheduler                 => '1.0.0',
+          :purge_config                            => false,
+          :block_device_allocate_retries           => '60',
+          :block_device_allocate_retries_interval  => '3',
+        }
       end
 
       it 'installs packages' do
@@ -126,6 +138,7 @@ describe 'nova' do
 
       it 'configures rabbit' do
         is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit')
+        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
@@ -159,6 +172,8 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova2')
         is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value('/var/locky/path')
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('120')
+        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
+        is_expected.to contain_nova_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('DEFAULT/notify_api_faults').with_value(true)
@@ -175,6 +190,10 @@ describe 'nova' do
         ) }
       end
 
+      it 'configures block_device_allocate params' do
+        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('60')
+        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('3')
+      end
     end
 
     context 'with wrong notify_on_state_change parameter' do
@@ -508,9 +527,9 @@ describe 'nova' do
       it { is_expected.to contain_nova_config('ssl/ca_file').with_value('/path/to/ca') }
       it { is_expected.to contain_nova_config('ssl/cert_file').with_value('/path/to/cert') }
       it { is_expected.to contain_nova_config('ssl/key_file').with_value('/path/to/key') }
-      it { is_expected.to contain_nova_config('DEFAULT/ssl_ca_file').with_value('/path/to/ca') }
-      it { is_expected.to contain_nova_config('DEFAULT/ssl_cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_nova_config('DEFAULT/ssl_key_file').with_value('/path/to/key') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_ca_file').with_value('/path/to/ca') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_cert_file').with_value('/path/to/cert') }
+      it { is_expected.to contain_nova_config('wsgi/ssl_key_file').with_value('/path/to/key') }
     end
 
     context 'with SSL socket options set with wrong parameters' do
@@ -545,49 +564,31 @@ describe 'nova' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian'
-      })
-    end
 
-    let :platform_params do
-      { :nova_common_package => 'nova-common',
-        :lock_path           => '/var/lock/nova' }
-    end
+  on_supported_os({
+    :supported_oos => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    it_behaves_like 'nova'
+      case facts[:osfamily]
+      when 'Debian'
+        let (:platform_params) do
+          { :nova_common_package => 'nova-common',
+            :lock_path           => '/var/lock/nova' }
+        end
+      when 'RedHat'
+        let (:platform_params) do
+          { :nova_common_package => 'openstack-nova-common',
+            :lock_path           => '/var/lib/nova/tmp' }
+        end
+      end
+
+      it_behaves_like 'nova'
+
+    end
   end
 
-  context 'on Ubuntu platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Ubuntu'
-      })
-    end
-
-    let :platform_params do
-      { :nova_common_package => 'nova-common',
-        :lock_path           => '/var/lock/nova' }
-    end
-
-    it_behaves_like 'nova'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :nova_common_package => 'openstack-nova-common',
-        :lock_path           => '/var/lib/nova/tmp' }
-    end
-
-    it_behaves_like 'nova'
-
-  end
 end
